install-i18n.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 97
c4086afea02b
--- a/install-i18n.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/install-i18n.py	Sat Jan 02 17:09:08 2010 +0000
@@ -3,10 +3,10 @@
 
 # Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric4's translation files.
 
 """
-Installation script for the eric4 IDE translation files.
+Installation script for the eric5 IDE translation files.
 """
 
 import sys
@@ -17,9 +17,9 @@
 from PyQt4.QtCore import QDir
 
 try:
-    from .eric4config import getConfig
+    from .eric5config import getConfig
 except ImportError:
-    print("The eric4 IDE doesn't seem to be installed. Aborting.")
+    print("The eric5 IDE doesn't seem to be installed. Aborting.")
     sys.exit(1)
     
 def getConfigDir():
@@ -119,4 +119,4 @@
         print("""An internal error occured.  Please report all the output of the program,
 including the following traceback, to eric5-bugs@eric-ide.python-projects.org.
 """)
-        raise
+        raise
\ No newline at end of file
@@ -3,10 +3,10 @@
 # Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the install script for eric4's translation files.
+# This is the install script for eric5's translation files.
 
 """

eric ide

mercurial